pub unsafe extern "C" fn CalcDDtable(
tableDeal: DdTableDeal,
tablep: *mut DdTableResults,
) -> c_intExpand description
@brief Calculate the double dummy table for a given Deal.
@param tableDeal Deal for which to calculate the table @param tablep Pointer to result table @return 1 on success, error code otherwise