#[repr(C)]pub struct Deal {
pub trump: c_int,
pub first: c_int,
pub currentTrickSuit: [c_int; 3],
pub currentTrickRank: [c_int; 3],
pub remainCards: [[c_uint; 4]; 4],
}Expand description
@brief Represents a bridge Deal for double dummy analysis.
@param trump The trump suit (0 = NT, 1 = Spades, …) @param first The hand to play first (0 = N, 1 = E, …) @param currentTrickSuit Suits of cards played in the current trick @param currentTrickRank Ranks of cards played in the current trick @param remainCards Remaining cards in each hand and suit
Fields
trump: c_intfirst: c_intcurrentTrickSuit: [c_int; 3]currentTrickRank: [c_int; 3]remainCards: [[c_uint; 4]; 4]Trait Implementations
impl Copy for Deal
impl Eq for Deal
impl StructuralPartialEq for Deal