pub unsafe extern "C" fn CalcDDtablePBN(
tableDealPBN: DdTableDealPBN,
tablep: *mut DdTableResults,
) -> c_intExpand description
@brief Calculate the double dummy table for a PBN Deal.
@param tableDealPBN PBN Deal for which to calculate the table @param tablep Pointer to result table @return 1 on success, error code otherwise