DealPBN

Struct DealPBN 

#[repr(C)]
pub struct DealPBN { pub trump: c_int, pub first: c_int, pub currentTrickSuit: [c_int; 3], pub currentTrickRank: [c_int; 3], pub remainCards: [c_char; 80], }
@brief Represents a bridge Deal in PBN (Portable Bridge Notation) format.

@param trump The trump suit @param first The hand to play first @param currentTrickSuit Suits of cards played in the current trick @param currentTrickRank Ranks of cards played in the current trick @param remainCards PBN string describing remaining cards

Fields

trump: c_intfirst: c_intcurrentTrickSuit: [c_int; 3]currentTrickRank: [c_int; 3]remainCards: [c_char; 80]